{% if image %}
    <label for="show-userlinks" class="bg-cover bg-no-repeat cursor-pointer flex font-semibold h-8 items-center justify-center rounded-full text-gray-500 text-xs w-8"
         style="background-image: url('{{ image.url }}')"></label>
{% elif initials %}
    <label for="show-userlinks" class="bg-gradient-to-tr border cursor-pointer from-gray-200 bg-gray-100 cursor-pointer flex font-semibold h-8 items-center justify-center rounded-full text-gray-500 text-xs uppercase w-8">
        {{ initials }}
    </label>
{% endif %}
